@@ -9,5 +9,12 @@ class PageBlock(models.Model):
     )
     block = models.CharField(max_length=255, db_index=True)
 
+    class Meta:
+        constraints = [
+            models.UniqueConstraint(
+                fields=["page", "block"], name="unique_page_block"
+            ),
+        ]
+
     def __str__(self):
         return "<{}, {}>".format(self.page, self.block)
